==> devops-client-java-1.0.0-sources.jar: io/alauda/devops/java/client/models/V1alpha1PipelineTemplateSyncSpecFluentImpl.java <==
package io.alauda.devops.java.client.models;

import com.google.gson.annotations.SerializedName;
import io.alauda.devops.java.client.fluent.Nested;
import java.lang.Deprecated;
import io.alauda.devops.java.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class V1alpha1PipelineTemplateSyncSpecFluentImpl<A extends V1alpha1PipelineTemplateSyncSpecFluent<A>> extends io.alauda.devops.java.client.fluent.BaseFluent<A> implements V1alpha1PipelineTemplateSyncSpecFluent<A>{

    private V1alpha1PipelineSourceBuilder source;

    public V1alpha1PipelineTemplateSyncSpecFluentImpl(){
    }
    public V1alpha1PipelineTemplateSyncSpecFluentImpl(V1alpha1PipelineTemplateSyncSpec instance){
            this.withSource(instance.getSource());

    }

    
/**
 * This method has been deprecated, please use method buildSource instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1PipelineSource getSource(){
            return this.source!=null?this.source.build():null;
    }

    public V1alpha1PipelineSource buildSource(){
            return this.source!=null?this.source.build():null;
    }

    public A withSource(V1alpha1PipelineSource source){
            _visitables.get("source").remove(this.source);
            if (source!=null){ this.source= new V1alpha1PipelineSourceBuilder(source); _visitables.get("source").add(this.source);} return (A) this;
    }

    public Boolean hasSource(){
            return this.source != null;
    }

    public V1alpha1PipelineTemplateSyncSpecFluent.SourceNested<A> withNewSource(){
            return new SourceNestedImpl();
    }

    public V1alpha1PipelineTemplateSyncSpecFluent.SourceNested<A> withNewSourceLike(V1alpha1PipelineSource item){
            return new SourceNestedImpl(item);
    }

    public V1alpha1PipelineTemplateSyncSpecFluent.SourceNested<A> editSource(){
            return withNewSourceLike(getSource());
    }

    public V1alpha1PipelineTemplateSyncSpecFluent.SourceNested<A> editOrNewSource(){
            return withNewSourceLike(getSource() != null ? getSource(): new V1alpha1PipelineSourceBuilder().build());
    }

    public V1alpha1PipelineTemplateSyncSpecFluent.SourceNested<A> editOrNewSourceLike(V1alpha1PipelineSource item){
            return withNewSourceLike(getSource() != null ? getSource(): item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1alpha1PipelineTemplateSyncSpecFluentImpl that = (V1alpha1PipelineTemplateSyncSpecFluentImpl) o;
            if (source != null ? !source.equals(that.source) :that.source != null) return false;
            return true;
    }


    public class SourceNestedImpl<N> extends V1alpha1PipelineSourceFluentImpl<V1alpha1PipelineTemplateSyncSpecFluent.SourceNested<N>> implements V1alpha1PipelineTemplateSyncSpecFluent.SourceNested<N>,io.alauda.devops.java.client.fluent.Nested<N>{

            private final V1alpha1PipelineSourceBuilder builder;
    
            SourceNestedImpl(V1alpha1PipelineSource item){
                    this.builder = new V1alpha1PipelineSourceBuilder(this, item);
            }
            SourceNestedImpl(){
                    this.builder = new V1alpha1PipelineSourceBuilder(this);
            }
    
    public N and(){
            return (N) V1alpha1PipelineTemplateSyncSpecFluentImpl.this.withSource(builder.build());
    }
    public N endSource(){
            return and();
    }

}


}

==> devops-client-java-1.0.6-sources.jar: io/alauda/devops/java/client/models/V1alpha1PipelineTemplateSyncSpecFluentImpl.java <==
package io.alauda.devops.java.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.alauda.devops.java.client.fluent.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import io.alauda.devops.java.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class V1alpha1PipelineTemplateSyncSpecFluentImpl<A extends V1alpha1PipelineTemplateSyncSpecFluent<A>> extends io.alauda.devops.java.client.fluent.BaseFluent<A> implements V1alpha1PipelineTemplateSyncSpecFluent<A>{

    private V1alpha1PipelineSourceBuilder source;
    private String strategy;

    public V1alpha1PipelineTemplateSyncSpecFluentImpl(){
    }
    public V1alpha1PipelineTemplateSyncSpecFluentImpl(V1alpha1PipelineTemplateSyncSpec instance){
            this.withSource(instance.getSource());

            this.withStrategy(instance.getStrategy());

    }

    
/**
 * This method has been deprecated, please use method buildSource instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1PipelineSource getSource(){
            return this.source!=null?this.source.build():null;
    }

    public V1alpha1PipelineSource buildSource(){
            return this.source!=null?this.source.build():null;
    }

    public A withSource(V1alpha1PipelineSource source){
            _visitables.get("source").remove(this.source);
            if (source!=null){ this.source= new V1alpha1PipelineSourceBuilder(source); _visitables.get("source").add(this.source);} return (A) this;
    }

    public Boolean hasSource(){
            return this.source != null;
    }

    public V1alpha1PipelineTemplateSyncSpecFluent.SourceNested<A> withNewSource(){
            return new SourceNestedImpl();
    }

    public V1alpha1PipelineTemplateSyncSpecFluent.SourceNested<A> withNewSourceLike(V1alpha1PipelineSource item){
            return new SourceNestedImpl(item);
    }

    public V1alpha1PipelineTemplateSyncSpecFluent.SourceNested<A> editSource(){
            return withNewSourceLike(getSource());
    }

    public V1alpha1PipelineTemplateSyncSpecFluent.SourceNested<A> editOrNewSource(){
            return withNewSourceLike(getSource() != null ? getSource(): new V1alpha1PipelineSourceBuilder().build());
    }

    public V1alpha1PipelineTemplateSyncSpecFluent.SourceNested<A> editOrNewSourceLike(V1alpha1PipelineSource item){
            return withNewSourceLike(getSource() != null ? getSource(): item);
    }

    public String getStrategy(){
            return this.strategy;
    }

    public A withStrategy(String strategy){
            this.strategy=strategy; return (A) this;
    }

    public Boolean hasStrategy(){
            return this.strategy != null;
    }

    public A withNewStrategy(String arg1){
            return (A)withStrategy(new String(arg1));
    }

    public A withNewStrategy(StringBuilder arg1){
            return (A)withStrategy(new String(arg1));
    }

    public A withNewStrategy(StringBuffer arg1){
            return (A)withStrategy(new String(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1alpha1PipelineTemplateSyncSpecFluentImpl that = (V1alpha1PipelineTemplateSyncSpecFluentImpl) o;
            if (source != null ? !source.equals(that.source) :that.source != null) return false;
            if (strategy != null ? !strategy.equals(that.strategy) :that.strategy != null) return false;
            return true;
    }


    public class SourceNestedImpl<N> extends V1alpha1PipelineSourceFluentImpl<V1alpha1PipelineTemplateSyncSpecFluent.SourceNested<N>> implements V1alpha1PipelineTemplateSyncSpecFluent.SourceNested<N>,io.alauda.devops.java.client.fluent.Nested<N>{

            private final V1alpha1PipelineSourceBuilder builder;
    
            SourceNestedImpl(V1alpha1PipelineSource item){
                    this.builder = new V1alpha1PipelineSourceBuilder(this, item);
            }
            SourceNestedImpl(){
                    this.builder = new V1alpha1PipelineSourceBuilder(this);
            }
    
    public N and(){
            return (N) V1alpha1PipelineTemplateSyncSpecFluentImpl.this.withSource(builder.build());
    }
    public N endSource(){
            return and();
    }

}


}
